@@ -19,7 +19,7 @@ use URI::Escape;
 
 __PACKAGE__->mk_accessors(qw/apikey config/);
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 $VERSION = eval $VERSION;  # see L<perlmodstyle>
 
 # Preloaded methods go here.
@@ -71,6 +71,9 @@ sub new {
     $self->{'limit'}            = $args->{'limit'} || $cfg->{'limit'};
     $self->{'group_map'}        = (defined($args->{'group_map'})) ? $args->{'group_map'} : $cfg->{'group_map'};
     $self->{'compress_address'} = $args->{'compress_address'} || $cfg->{'compress_address'};
+    $self->{'round_confidence'} = $args->{'round_confidence'} || $cfg->{'round_confidence'};
+
+    $self->{'proxy'}            = $args->{'proxy'} || $cfg->{'proxy'};
     
     if($args->{'fields'}){
         @{$self->{'fields'}} = split(/,/,$args->{'fields'}); 
@@ -80,6 +83,11 @@ sub new {
         $self->getUseragent->ssl_opts(verify_hostname => 0);
     }
 
+    if($self->{'proxy'}){
+        warn 'setting proxy' if($::debug);
+        $self->getUseragent->proxy(['http','https'],$self->{'proxy'});
+    }
+
     return($self);
 }
 
@@ -115,7 +123,6 @@ sub GET  {
 
     $self->SUPER::GET($rest);
     my $content = $self->{'_res'}->{'_content'};
-    warn $content if($::debug);
     return unless($content);
     return unless($self->responseCode == 200);
     my $text = $self->responseContent();
@@ -131,6 +138,12 @@ sub GET  {
     ## TODO -- finish implementing this into the config
     if($self->{'simple_hashes'}){
         $self->hash_simple($hash);
+        if($self->{'round_confidence'}){
+            foreach (@{$hash->{'data'}->{'feed'}->{'entry'}}){
+                # we're rouding down on purpose
+                $_->{'confidence'} = int($_->{'confidence'});
+            }
+        }
     }
     return($hash->{'data'});
 }       
